function isURL(s) {
  return /(ftp|http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!-/]))?/
    .test(s)
}

var id2enginemap = {
  'google': 'https://www.google.com/search?q=',
  'yahoo': 'https://search.yahoo.com/search?q=',
  'bing': 'https://bing.com/search?q=',
  'baidu': 'https://www.baidu.com/s?wd=',
  'yandex': 'https://yandex.com/search/?text='
}

chrome.runtime.onMessage.addListener(function(message, sender, sendResponse) {
  const isUrl = isURL(unescape(decodeURIComponent(message.c)))
  console.log(message.c, isUrl)

  chrome.tabs.query({
    active: true,
    currentWindow: true
  }, function(tabs) {
    if (tabs && tabs.length > 0) {
      var current = tabs[tabs.length - 1]
      var index = current.index

      chrome.storage.sync.get('tabmode', function(o) {
        var foreground = false
        if (o && o.tabmode) {
          foreground = (o.tabmode === 'foreground')
        } else {
          foreground = false
        }

        if (isUrl) {
          chrome.tabs.create({
            url: decodeURIComponent(message.c),
            index: index + 1,
            active: message.foreground || foreground
          })
        } else {
          chrome.storage.sync.get('engine', function(o) {
            if (o && o.engine) {
              chrome.tabs.create({
                url: id2enginemap[o.engine] + message.c,
                index: index + 1,
                active: message.foreground || foreground
              })
            } else {
              chrome.tabs.create({
                url: id2enginemap['google'] + message.c,
                index: index + 1,
                active: message.foreground || foreground
              })
            }
          })
        }
      })
    }
  })
})

chrome.runtime.onInstalled.addListener(function(details) {
  chrome.tabs.query({}, function(tabs) {
    for (var i = 0; i < tabs.length; i++) {
      if (~tabs[i].url.indexOf('http')) {
        chrome.tabs.executeScript(tabs[i].id, {
          'file': 'superdrag.js'
        })
      }
    }
  })
})
